PsaResultCode

Enum PsaResultCode 

pub enum PsaResultCode {
    Success,
    InvalidArgument,
    NotPermitted,
    InvalidHandle,
    BufferTooSmall,
    NotSupported,
    InvalidSignature,
    GenericError,
}
Enumerates normalized PSA status classes used by the public adapter layer.

Variants



Success

The operation completed successfully.



InvalidArgument

A supplied argument or encoded payload is invalid.



NotPermitted

The requested operation is not permitted by key policy.



InvalidHandle

The key handle is unknown or no longer valid.



BufferTooSmall

Operation failed because output or input buffer sizes are insufficient.



NotSupported

Operation failed due to capability not present in the target backend.



InvalidSignature

Signature, MAC, or decrypt checks failed.



GenericError

A generic backend failure was returned.